---
title: Unit Tests
hide:
    - footer
---

Unit tests are especially helpful for `django-simple-deploy`, because they let you verify that the project is working without making any external calls, and without creating any new resources on external platforms. For this reason, unit tests focus entirely on the *configuration* process, not on the *deployment* process.
